@@ -28,12 +28,17 @@
 class ContactManager
 {
 public:
+    struct Name
+    {
+        QString firstname;
+        QString surname;
+    };
+
     struct Contact
     {
-        QString name;
+        Name name;
         QString number;
         QString street;
-        QString streetNumber;
         QString zipCode;
         QString city;
         QString country;
@@ -43,6 +48,7 @@ public:
     ~ContactManager();
     bool addContact(Contact const& contact);
     bool numberExists(QString const& number);
+    static void stringToName(QString const& strname, Name& name);
 
 private:
     bool load();
