@@ -25,7 +25,7 @@ namespace
     {
             "http://wap.eniro.fi/",
             "http://wap.eniro.se/",
-            "http://wap.eniro.dk/"
+            "http://m.krak.dk/"
     };
 
     static const QString SITE_NAMES[Eniro::SITE_COUNT] =
@@ -430,6 +430,7 @@ void Eniro::loadResults(int id, QString const& httpData)
         // Otherwise result is ready
         else
         {
+            it.value()->foundNumbers++;
             emit resultAvailable(result, it.value()->details);
         }
 
