@@ -35,6 +35,8 @@ public:
     ResultWindow(QWidget* parent = 0);
     ~ResultWindow();
     static const int REQUEST_TIMEOUT = 30000;
+    static const int SEARCH_INTERVAL = 1000;
+    static const int RETRIES = 2;
 
 signals:
     void itemSelected(Source::Result const& result);
@@ -43,6 +45,9 @@ public slots:
     void search(SearchDialog::SearchDetails& details);
     virtual void setVisible(bool visible);
 
+protected:
+    virtual void timerEvent(QTimerEvent* event);
+
 private slots:
     void resultAvailable(Source::Result const& result, Source::SearchDetails const& details);
     void requestFinished(QVector <Source::Result> const& results, Source::SearchDetails const& details, bool error);
@@ -53,6 +58,10 @@ private:
     Source* source_;
     QListWidget* list_;
     ConnectionManager* connectionManager_;
+    int timer_;
+    bool searching_;
+    int retries_;
+    Source::SearchDetails currentSearch_;
 
 };
 
